import { assert } from 'console';
import { findStartTime } from './gpx';

describe('findStartTime', () => {
  test('to be undefined for a string', () => {
    const start = findStartTime('');
    expect(start).toBeUndefined();
  });
  test('to be undefined for an object without time key', () => {
    const start = findStartTime({ foo: 'foo', bar: 'bar' });
    expect(start).toBeUndefined();
  });
  test('to be the time value for an object with a time key', () => {
    const start = findStartTime({ foo: 'foo', time: 'bar' });
    expect(start).toEqual('bar');
  });
  test('to be the lowest time value for an object with several time keys', () => {
    const start = findStartTime({
      foo: { time: 'foo' },
      time: 'bar',
      bar: { time: 'a' },
    });
    expect(start).toEqual('a');
  });
  test('to be the lowest time value for an array with several objects with time keys', () => {
    const start = findStartTime({
      foos: [{ time: 'foo' }, { time: '0' }],
      time: 'bar',
      bar: { time: 'a' },
    });
    expect(start).toEqual('0');
  });
});
